==> sleet-0.1.dev6-py3-none-any.whl: sleet/oauth.py <==
"""
This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
"""

import json
import logging
from base64 import b64encode
from datetime import datetime, timedelta

from urllib3 import PoolManager
from urllib3.exceptions import HTTPError

from sleet.constants import DEFAULT_CLIENT_HEADERS
from sleet.exceptions import APIStatusError, SleetError

logger = logging.getLogger(__name__)


class OAuth:
    _token: str = ""

    def __init__(self, region: str, client_id: str, client_secret: str):
        self.oauth_url = f"https://{region}.battle.net/oauth/token?grant_type=client_credentials"
        self.client_id = client_id
        self.client_secret = client_secret
        self.token_expiry = datetime.utcnow() - timedelta(1)
        self.client: PoolManager = PoolManager(headers=DEFAULT_CLIENT_HEADERS)

    @property
    def token(self) -> str:
        if self._has_token_expired():
            if self._token:
                logger.info(f"Token {self._token} has expired.")
            self._token_refresh()

        return self._token

    @token.setter
    def token(self, value: str) -> None:
        self._token = value

    def _has_token_expired(self) -> bool:
        return (self.token_expiry - datetime.utcnow()).total_seconds() < 5400

    def _token_refresh(self) -> None:
        credentials = f"{self.client_id}:{self.client_secret}"

        authorization_header = {
            "Authorization": f"Basic {b64encode(credentials.encode()).decode()}"
        }

        try:
            response = self.client.request("POST", self.oauth_url, headers=self.client.headers | authorization_header)

        except HTTPError as ex:
            raise SleetError(f"Error querying {self.oauth_url}.") from ex

        if response.status != 200:
            raise APIStatusError(response.status)

        try:
            data = json.loads(response.data)

        except json.JSONDecodeError as ex:
            logger.error(f"Failed to obtain new token. Exception: {ex}.")
            raise SleetError(f"Failed to obtain new token. Exception: {ex}.")

        else:
            self.token = data["access_token"]
            self.token_expiry = datetime.utcnow() + timedelta(seconds=data["expires_in"])
            logger.info(f"New token is {self._token}, expires at {self.token_expiry}.")

==> sleet-1.0-py3-none-any.whl: sleet/oauth.py <==
"""
This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
"""

import json
import logging
from base64 import b64encode
from datetime import datetime, timedelta

from urllib3 import PoolManager
from urllib3.exceptions import HTTPError

from sleet.constants import DEFAULT_CLIENT_HEADERS
from sleet.exceptions import APIStatusError, SleetError

logger = logging.getLogger(__name__)


class OAuth:
    _token: str = ""

    def __init__(self, region: str, client_id: str, client_secret: str):
        # APAC is short for Asia-Pacific and replaces the previously-used kr and tw regions.
        # https://develop.battle.net/documentation/guides/using-oauth
        if region in ("kr", "tw"):
            region = "apac"

        self.client: PoolManager = PoolManager(headers=DEFAULT_CLIENT_HEADERS)
        self.client_id = client_id
        self.client_secret = client_secret
        self.oauth_url = f"https://{region}.battle.net/oauth/token?grant_type=client_credentials"
        self.token_expiry = datetime.utcnow() - timedelta(1)

    @property
    def token(self) -> str:
        """
        TODO: Fill in.

        :return:
        """
        if self._has_token_expired():
            if self._token:
                logger.info(f"Token {self._token} has expired.")

            self._token_refresh()

        return self._token

    @token.setter
    def token(self, value: str) -> None:
        """
        TODO: Fill in.

        :param value:
        :return:
        """
        self._token = value

    def _has_token_expired(self) -> bool:
        """
        TODO: Fill in.

        :return:
        """
        return (self.token_expiry - datetime.utcnow()).total_seconds() < 5400

    def _token_refresh(self) -> None:
        """
        TODO: Fill in.

        :return:
        """
        credentials = f"{self.client_id}:{self.client_secret}"

        headers = self.client.headers | {"Authorization": f"Basic {b64encode(credentials.encode()).decode()}"}

        try:
            response = self.client.request("POST", self.oauth_url, headers=headers)

        except HTTPError as ex:
            raise SleetError(f"Error querying {self.oauth_url}.") from ex

        if response.status != 200:
            raise APIStatusError(response.status)

        try:
            data = json.loads(response.data)

        except json.JSONDecodeError as ex:
            logger.error(f"Failed to obtain new token. Exception: {ex}.")
            raise SleetError(f"Failed to obtain new token. Exception: {ex}.")

        else:
            self.token = data["access_token"]
            self.token_expiry = datetime.utcnow() + timedelta(seconds=data["expires_in"])
            logger.info(f"New token is {self._token}, expires at {self.token_expiry}.")
